# This file acts both as a sample as well as quick-start to run the backup
# scripts to backup primary server onto a backup server.
#
# Those that have defaults are commented and are given here just for
# informational purpose.
#
# On windows, use only forward-slashes in paths and DON'T use cygwin paths.
#

##
## START of basic configuration parameters.
##

# We assume that the user specified here has "root" privileages.
# The username is used for both remote and local perforce servers.
p4User = None

p4HostRemote = None
# Remote perforce server related configuration.
p4PortRemote = p4HostRemote+':1666'
# The location of the journal (P4JOURNAL value) for the remote perforce server.
# All journals and checkpoitns are assumed to be generated in the same
# directory.
p4JournalRemote = None

# The local perforce server will be bound to this port.
# It is recommended that "localhost" be used for the host part such that
# developers would not accidentally connect to it.
p4PortLocal = 'localhost:1666'
# The location of the journal (P4JOURNAL value) for the local perforce server.
p4JournalLocal = None
p4RootLocal = None

# Windows service name to start perforce.
# Required only for windows.
#p4ServiceNameLocal = "Perforce"

smtpServer = None
fromAddr = None
# Comma separated list of email ids.
toAddrs = []
ccAddrs = []

# Set this to True when script package is checked in to perforce, or False when
# it is a stand-alone install. This enables the script to pulldown any updates
# done in perforce and reload the modules. The structure of the scripts and cfg
# directory is still assumed to be the same.
packageInPerforce = False

# This is the client used to access local perforce server from local m/c. This
#   can be set to the same value as p4ClientRemote.
# If set, will also be used to restrict the view for "p4 verify". This is useful
#   to exclude any files that are currently known to fail verify.
p4ClientLocal = None
# The following two options are required only if packageInPerforce is True.
# This is the client used to access remote perforce server from local m/c.
p4ClientRemote = None
# This is the client used to access remote perforce server from remote m/c.
# Used mainly to determine the client root on the remote server.
# Required only for windows.
p4RemoteClient = None

##
## END of basic configuration parameters.
##

# Sync options
# Files under perforce root that need to be synchronized.
# Append a "/" for directories. You can use wildcards for filenames.
# CAUTION: There should be at least one comma.
#syncScmFiles = ('depot/',)

# This is the path to a file containing exclusion patterns to speed up the
#   rsync for quick-sync run. This list is basically a list of all the
#   directories (mostly branches) that are retired or not likely to have regular
#   changes.
# The path is relative to the parent directory of the scripts directory.
# If not set, the quick-sync mode will be disabled.
#quickRsyncExcludeFile = None

# The rsync configuration filename. If set, rsync is run in the daemon mode on
#   the remote host. This is the recommended way on windows, as cygwin is known
#   to cause hangs if rsync is run over remote shell.
# This is a relative path to the parent directory of the scripts directory.
# If packageInPerforce is True, this file is also assumed to be in perforce and
#   remote location is determined by using the p4RemoteClient client
#   specification.
# If scripts are not under perforce, the file <rsyncConfigFileName> is first
#   copied to the directory specified by <rsyncRemoteConfDir> on the remote
#   machine.
# The following two modules are expected to be defined in this file to export the
#   files to rsync:
#       perforceroot: the perforce root directory containing depot etc.
#       perforcejournals: the directory containing the journal
#           (P4JOURNAL/p4JournalRemote).
#rsyncConfigFileName = None

# The following option is required only if rsyncConfigFileName is not None (ie.,
#   the rsync daemon mode is chosen) and packageInPerforce is False.
# If scripts are not under perforce, it specifies the absolute location of the
#   file on the remote host to which the file specified by rsyncConfigFileName
#   should be copied to. The file is copied using rcp/scp depending on the
#   choice of remoteShell.
#rsyncRemoteConfDir = None

# If None, file logging will be disabled. When scripts are in perforce, this
# should be a relative path to the parent directory of the scripts directory.
#logFile = "logs/p4admin.log.txt"

# If set, this will be given as a network path to the logfile in notifications.
#   Useful for windows to specify CIFS paths, when the directory containing the
#   logfile is shared.
#logFileShared = None

# The options passed to rsync. This should at least include "-a" option or its
# equivalents.
#rsyncOpts = '--stats -av'

# Interval between two quick-sync runs in seconds..
#quickSyncRunInterval = 30*60 # 30min

# Sends a notification if run hasn't completed in the specified duration.
#quickSyncExpectedRunDuration = datetime.timedelta(hours=1)

# Set to True to enable this job.
#quickSyncEnabled = False

# Sends a notification email after every completion of run with the status.
#quickSyncNotifyRun = False

# The time (24hr format) at which the full sync is run every day.
#fullSyncFirstRun = "20:00:00" # 8pm

# Sends a notification email after every completion of run with the status.
#fullSyncNotifyRun = False

# Sends a notification if run hasn't completed in the specified duration.
#fullSyncExpectedRunDuration = datetime.timedelta(hours=3)

# The time (24hr format) at which the checkpoint is run every day.
#checkpointFirstRun = "21:00:00" # 9pm

# Sends a notification email after every completion of run with the status.
#checkpointNotifyRun = False

# Sends a notification if run hasn't completed in the specified duration.
#checkpointExpectedRunDuration = datetime.timedelta(hours=2)

# Set to True to enable this job.
#checkpointEnabled = True

# Set to True to enable this job.
#fullSyncEnabled = True

# The weekday (0-6) and time (24hr format) at which the verify runs every week.
#verifyFirstRun = "5,22:00:00" # Saturday, 10pm

# Sends a notification email after every completion of run with the status.
#verifyNotifyRun = False

# Sends a notification if run hasn't completed in the specified duration.
#verifyExpectedRunDuration = datetime.timedelta(hours=15)

# Set to True to enable this job.
#verifyEnabled = True

# Setting this to True causes the win32p4adminsvc.py module to call atexit
#   functions manually as workaround for pywin32 bug. The bug existed as of
#   ActiveState Python 2.4.1 Build 247, based on Python 2.4.1 (#65, Jun 20 2005,
#   17:01:55).
# If you see "closing log" message twice or you see other weird exceptions (such
#   as logging trying to close the log file twice) while stopping win32 service,
#   that means the bug is fixed and so you should set this to False.
workaroundPythonWin32ServiceAtexitBug = True
